[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# Real-Time Time Series client library for Python

[![API Version](https://img.shields.io/badge/api-v3.0.0-blue)](https://developer.factset.com/api-catalog/)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.RealTimeTimeSeries/0.11.7)](https://pypi.org/project/fds.sdk.RealTimeTimeSeries/v/0.11.7)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

Time series data, end-of-day or intraday, tick-by-tick or subsampled. Additional vendor-specific endpoints provide a modified interface
for seamless integration with the ChartIQ chart library.

This API is focused on high-performance applications that are

* serving millions of end-users,
* accessible by client browsers via the internet,
* integrated into complex infrastructures such as existing frontend frameworks or authentication services.

This API has been designed for direct use by client web applications and feature extreme low latency:
The average response time across all endpoints is 30 ms whereas 99% of all requests are answered in close to under 300ms.

See the [Real-Time Quotes API for Digital Portals](https://developer.factset.com/api-catalog/real-time-quotes-api) for access to detailed
price information.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.0.0
- SDK version: 0.11.7
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.RealTimeTimeSeries==0.11.7
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.RealTimeTimeSeries==0.11.7
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.RealTimeTimeSeries
from fds.sdk.RealTimeTimeSeries.api import prices_api
from fds.sdk.RealTimeTimeSeries.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.RealTimeTimeSeries.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.RealTimeTimeSeries.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.RealTimeTimeSeries.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = prices_api.PricesApi(api_client)
    post_prices_time_series_eod_list_request = PostPricesTimeSeriesEodListRequest(
        data=PostVendorChartIQTimeSeriesEodListRequestData(
            identifier=PostVendorChartIQTimeSeriesEodListRequestDataIdentifier(
                value="80728880015",
                type="idNotation",
            ),
            type="trade",
            quality="DLY",
            range=PostVendorChartIQTimeSeriesEodListRequestDataRange(
                start=dateutil_parser('1970-01-01').date(),
                end=dateutil_parser('1970-01-01').date(),
            ),
            newest_first=False,
            adjustments=PostVendorChartIQTimeSeriesEodListRequestDataAdjustments(
                payout=False,
                split=True,
            ),
        ),
        meta=PostVendorChartIQTimeSeriesEodListRequestMeta(
            attributes=AttributesMember([
                "attributes_example",
            ]),
            pagination=PostVendorChartIQTimeSeriesEodListRequestMetaPagination(
                cursor="cursor_example",
                limit=20,
            ),
        ),
    ) # PostPricesTimeSeriesEodListRequest | Request Body

    try:
        # End-of-day time series data for a notation.
        # example passing only required values which don't have defaults set
        api_response = api_instance.post_prices_time_series_eod_list(post_prices_time_series_eod_list_request)

        pprint(api_response)
    except fds.sdk.RealTimeTimeSeries.ApiException as e:
        print("Exception when calling PricesApi->post_prices_time_series_eod_list: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # End-of-day time series data for a notation.
    #     api_response, http_status_code, response_headers = api_instance.post_prices_time_series_eod_list_with_http_info(post_prices_time_series_eod_list_request)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.RealTimeTimeSeries.ApiException as e:
    #     print("Exception when calling PricesApi->post_prices_time_series_eod_list: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # End-of-day time series data for a notation.
    #     async_result = api_instance.post_prices_time_series_eod_list_async(post_prices_time_series_eod_list_request)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.RealTimeTimeSeries.ApiException as e:
    #     print("Exception when calling PricesApi->post_prices_time_series_eod_list: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # End-of-day time series data for a notation.
    #     async_result = api_instance.post_prices_time_series_eod_list_with_http_info_async(post_prices_time_series_eod_list_request)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.RealTimeTimeSeries.ApiException as e:
    #     print("Exception when calling PricesApi->post_prices_time_series_eod_list: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.RealTimeTimeSeries

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.RealTimeTimeSeries.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.RealTimeTimeSeries

configuration = fds.sdk.RealTimeTimeSeries.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.RealTimeTimeSeries

configuration = fds.sdk.RealTimeTimeSeries.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.RealTimeTimeSeries

configuration = fds.sdk.RealTimeTimeSeries.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/wealth/v3*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PricesApi* | [**post_prices_time_series_eod_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PricesApi.md#post_prices_time_series_eod_list) | **POST** /prices/timeSeries/eod/list | End-of-day time series data for a notation.
*PricesApi* | [**post_prices_time_series_eod_subsample_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PricesApi.md#post_prices_time_series_eod_subsample_get) | **POST** /prices/timeSeries/eod/subsample/get | Single subsample end-of-day data for a notation.
*PricesApi* | [**post_prices_time_series_eod_subsample_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PricesApi.md#post_prices_time_series_eod_subsample_list) | **POST** /prices/timeSeries/eod/subsample/list | Subsampled end-of-day time series data for a notation.
*PricesApi* | [**post_prices_time_series_intraday_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PricesApi.md#post_prices_time_series_intraday_list) | **POST** /prices/timeSeries/intraday/list | Intraday time series data for a notation.
*PricesApi* | [**post_prices_time_series_intraday_subsample_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PricesApi.md#post_prices_time_series_intraday_subsample_get) | **POST** /prices/timeSeries/intraday/subsample/get | Single subsample intraday data for a notation.
*PricesApi* | [**post_prices_time_series_intraday_subsample_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PricesApi.md#post_prices_time_series_intraday_subsample_list) | **POST** /prices/timeSeries/intraday/subsample/list | Subsampled intraday time series data for a notation.
*VendorApi* | [**post_vendor_chart_iq_time_series_eod_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/VendorApi.md#post_vendor_chart_iq_time_series_eod_list) | **POST** /vendor/chartIQ/timeSeries/eod/list | End-of-day time series data for a notation.
*VendorApi* | [**post_vendor_chart_iq_time_series_eod_subsample_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/VendorApi.md#post_vendor_chart_iq_time_series_eod_subsample_get) | **POST** /vendor/chartIQ/timeSeries/eod/subsample/get | Single subsample end-of-day data for a notation.
*VendorApi* | [**post_vendor_chart_iq_time_series_eod_subsample_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/VendorApi.md#post_vendor_chart_iq_time_series_eod_subsample_list) | **POST** /vendor/chartIQ/timeSeries/eod/subsample/list | Subsampled end-of-day time series data for a notation.
*VendorApi* | [**post_vendor_chart_iq_time_series_intraday_subsample_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/VendorApi.md#post_vendor_chart_iq_time_series_intraday_subsample_get) | **POST** /vendor/chartIQ/timeSeries/intraday/subsample/get | Single subsample intraday data for a notation.
*VendorApi* | [**post_vendor_chart_iq_time_series_intraday_subsample_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/VendorApi.md#post_vendor_chart_iq_time_series_intraday_subsample_list) | **POST** /vendor/chartIQ/timeSeries/intraday/subsample/list | Subsampled intraday time series data for a notation.


## Documentation For Models

 - [AttributesMember](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/AttributesMember.md)
 - [CursorBasedPaginationOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/CursorBasedPaginationOutputObject.md)
 - [CursorBasedPaginationOutputObjectWithoutTotal](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/CursorBasedPaginationOutputObjectWithoutTotal.md)
 - [ErrorMetaObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/ErrorMetaObject.md)
 - [ErrorObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/ErrorObject.md)
 - [InlineResponse200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse200.md)
 - [InlineResponse2001](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2001.md)
 - [InlineResponse20010](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse20010.md)
 - [InlineResponse20010Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse20010Data.md)
 - [InlineResponse20010DataSubsamples](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse20010DataSubsamples.md)
 - [InlineResponse2001Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2001Data.md)
 - [InlineResponse2001Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2001Meta.md)
 - [InlineResponse2002](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2002.md)
 - [InlineResponse2002Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2002Data.md)
 - [InlineResponse2003](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2003.md)
 - [InlineResponse2003Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2003Data.md)
 - [InlineResponse2004](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2004.md)
 - [InlineResponse2004Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2004Data.md)
 - [InlineResponse2004DataRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2004DataRange.md)
 - [InlineResponse2005](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2005.md)
 - [InlineResponse2005Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2005Data.md)
 - [InlineResponse2005DataPrices](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2005DataPrices.md)
 - [InlineResponse2006](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2006.md)
 - [InlineResponse2006Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2006Data.md)
 - [InlineResponse2006DataSubsample](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2006DataSubsample.md)
 - [InlineResponse2007](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2007.md)
 - [InlineResponse2007Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2007Data.md)
 - [InlineResponse2007DataSubsamples](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2007DataSubsamples.md)
 - [InlineResponse2008](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2008.md)
 - [InlineResponse2008Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2008Data.md)
 - [InlineResponse2008DataPrices](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2008DataPrices.md)
 - [InlineResponse2009](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2009.md)
 - [InlineResponse2009Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2009Data.md)
 - [InlineResponse2009DataSubsample](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse2009DataSubsample.md)
 - [InlineResponse200Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse200Data.md)
 - [InlineResponse200DataRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse200DataRange.md)
 - [InlineResponse200Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/InlineResponse200Meta.md)
 - [LanguageMember](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/LanguageMember.md)
 - [OffsetBasedPaginationOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/OffsetBasedPaginationOutputObject.md)
 - [OffsetBasedPaginationOutputObjectWithoutTotal](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/OffsetBasedPaginationOutputObjectWithoutTotal.md)
 - [PartialOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PartialOutputObject.md)
 - [PostPricesTimeSeriesEodListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesEodListRequest.md)
 - [PostPricesTimeSeriesEodSubsampleGetRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesEodSubsampleGetRequest.md)
 - [PostPricesTimeSeriesEodSubsampleGetRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesEodSubsampleGetRequestData.md)
 - [PostPricesTimeSeriesEodSubsampleGetRequestDataInterval](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesEodSubsampleGetRequestDataInterval.md)
 - [PostPricesTimeSeriesEodSubsampleListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesEodSubsampleListRequest.md)
 - [PostPricesTimeSeriesIntradayListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesIntradayListRequest.md)
 - [PostPricesTimeSeriesIntradayListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesIntradayListRequestData.md)
 - [PostPricesTimeSeriesIntradayListRequestDataRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesIntradayListRequestDataRange.md)
 - [PostPricesTimeSeriesIntradayListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesIntradayListRequestMeta.md)
 - [PostPricesTimeSeriesIntradayListRequestMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesIntradayListRequestMetaPagination.md)
 - [PostPricesTimeSeriesIntradaySubsampleGetRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesIntradaySubsampleGetRequest.md)
 - [PostPricesTimeSeriesIntradaySubsampleListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostPricesTimeSeriesIntradaySubsampleListRequest.md)
 - [PostVendorChartIQTimeSeriesEodListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodListRequest.md)
 - [PostVendorChartIQTimeSeriesEodListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodListRequestData.md)
 - [PostVendorChartIQTimeSeriesEodListRequestDataAdjustments](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodListRequestDataAdjustments.md)
 - [PostVendorChartIQTimeSeriesEodListRequestDataIdentifier](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodListRequestDataIdentifier.md)
 - [PostVendorChartIQTimeSeriesEodListRequestDataRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodListRequestDataRange.md)
 - [PostVendorChartIQTimeSeriesEodListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodListRequestMeta.md)
 - [PostVendorChartIQTimeSeriesEodListRequestMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodListRequestMetaPagination.md)
 - [PostVendorChartIQTimeSeriesEodSubsampleGetRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodSubsampleGetRequest.md)
 - [PostVendorChartIQTimeSeriesEodSubsampleGetRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodSubsampleGetRequestData.md)
 - [PostVendorChartIQTimeSeriesEodSubsampleGetRequestDataInterval](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodSubsampleGetRequestDataInterval.md)
 - [PostVendorChartIQTimeSeriesEodSubsampleGetRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodSubsampleGetRequestMeta.md)
 - [PostVendorChartIQTimeSeriesEodSubsampleListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodSubsampleListRequest.md)
 - [PostVendorChartIQTimeSeriesEodSubsampleListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodSubsampleListRequestData.md)
 - [PostVendorChartIQTimeSeriesEodSubsampleListRequestDataIntervalSelection](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodSubsampleListRequestDataIntervalSelection.md)
 - [PostVendorChartIQTimeSeriesEodSubsampleListRequestDataIntervalSelectionSamples](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesEodSubsampleListRequestDataIntervalSelectionSamples.md)
 - [PostVendorChartIQTimeSeriesIntradaySubsampleGetRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesIntradaySubsampleGetRequest.md)
 - [PostVendorChartIQTimeSeriesIntradaySubsampleGetRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesIntradaySubsampleGetRequestData.md)
 - [PostVendorChartIQTimeSeriesIntradaySubsampleGetRequestDataAdjustments](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesIntradaySubsampleGetRequestDataAdjustments.md)
 - [PostVendorChartIQTimeSeriesIntradaySubsampleListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesIntradaySubsampleListRequest.md)
 - [PostVendorChartIQTimeSeriesIntradaySubsampleListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesIntradaySubsampleListRequestData.md)
 - [PostVendorChartIQTimeSeriesIntradaySubsampleListRequestDataRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/PostVendorChartIQTimeSeriesIntradaySubsampleListRequestDataRange.md)
 - [StatusObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/RealTimeTimeSeries/v3/docs/StatusObject.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.RealTimeTimeSeries.apis and fds.sdk.RealTimeTimeSeries.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.RealTimeTimeSeries.api.default_api import DefaultApi`
- `from fds.sdk.RealTimeTimeSeries.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.RealTimeTimeSeries
from fds.sdk.RealTimeTimeSeries.apis import *
from fds.sdk.RealTimeTimeSeries.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

